@@ -2,7 +2,7 @@ from collections import namedtuple
 from functools import partial
 from itertools import groupby
 from math import ceil
-from struct import Struct, unpack
+from struct import Struct
 from sqlite3 import connect
 
 
@@ -13,6 +13,7 @@ def stream_sqlite(sqlite_chunks):
     unsigned_char = Struct('B')
     unsigned_short = Struct('>H')
     unsigned_long = Struct('>L')
+    double = Struct('>d')
     table_leaf_header = Struct('>HHHB')
     table_interior_header = Struct('>HHHBL')
     index_interior_header = Struct('>HHHBL')
@@ -166,7 +167,7 @@ def stream_sqlite(sqlite_chunks):
                         yield h
                         header_remaining -= v_size
 
-                for pointer in pointers:
+                for pointer, in pointers:
                     cell_num_reader, cell_varint_reader = get_chunk_readers(page_bytes, pointer)
 
                     payload_size, _ = cell_varint_reader()
@@ -186,6 +187,7 @@ def stream_sqlite(sqlite_chunks):
                             (4, lambda raw: int.from_bytes(raw, byteorder='big', signed=True)) if serial_type == 4 else \
                             (6, lambda raw: int.from_bytes(raw, byteorder='big', signed=True)) if serial_type == 5 else \
                             (8, lambda raw: int.from_bytes(raw, byteorder='big', signed=True)) if serial_type == 6 else \
+                            (8, lambda raw: double.unpack(raw)[0]) if serial_type == 7 else \
                             (0, lambda _: 0) if serial_type == 8 else \
                             (0, lambda _: 1) if serial_type == 9 else \
                             (int((serial_type - 12)/2), lambda raw: raw) if serial_type % 2 == 0 else \
@@ -195,10 +197,11 @@ def stream_sqlite(sqlite_chunks):
                     )
 
             def process_table_leaf_master():
-                first_free_block, num_cells, cell_content_start, num_frag_free = \
+                _, num_cells, _, _ = \
                     table_leaf_header.unpack(page_reader(7))
 
-                pointers = unpack('>{}H'.format(num_cells), page_reader(num_cells * 2))
+                pointers = unsigned_short.iter_unpack(page_reader(num_cells * 2))
+
                 for table_or_index, table_name, (table_info, row_constructor), root_page in get_master_table(yield_leaf_table_cells(pointers)):
                     yield from (
                         process_if_buffered_or_remember(partial(process_table_page, table_name, table_info, row_constructor), root_page) if table_or_index == 'table' else \
@@ -206,10 +209,10 @@ def stream_sqlite(sqlite_chunks):
                     )
 
             def process_table_leaf_non_master():
-                first_free_block, num_cells, cell_content_start, num_frag_free = \
+                _, num_cells, _, _ = \
                     table_leaf_header.unpack(page_reader(7))
 
-                pointers = unpack('>{}H'.format(num_cells), page_reader(num_cells * 2))
+                pointers = unsigned_short.iter_unpack(page_reader(num_cells * 2))
 
                 yield table_name, table_info, (
                     row_constructor(*cell)
@@ -217,12 +220,12 @@ def stream_sqlite(sqlite_chunks):
                 )
 
             def process_table_interior():
-                first_free_block, num_cells, cell_content_start, num_frag_free, right_most_pointer = \
+                _, num_cells, _, _, right_most_pointer = \
                     table_interior_header.unpack(page_reader(11))
 
-                pointers = unpack('>{}H'.format(num_cells), page_reader(num_cells * 2))
+                pointers = unsigned_short.iter_unpack(page_reader(num_cells * 2))
 
-                for pointer in pointers:
+                for pointer, in pointers:
                     cell_num_reader, cell_varint_reader = get_chunk_readers(page_bytes, pointer)
                     page_number, =  unsigned_long.unpack(cell_num_reader(4))
                     yield from process_if_buffered_or_remember(
@@ -244,12 +247,12 @@ def stream_sqlite(sqlite_chunks):
                 yield from ()
 
             def process_index_interior():
-                first_free_block, num_cells, cell_content_start, num_frag_free, right_most_pointer = \
+                _, num_cells, _, _, right_most_pointer = \
                     index_interior_header.unpack(page_reader(11))
 
-                pointers = unpack('>{}H'.format(num_cells), page_reader(num_cells * 2))
+                pointers = unsigned_short.iter_unpack(page_reader(num_cells * 2))
 
-                for pointer in pointers:
+                for pointer, in pointers:
                     cell_num_reader, cell_varint_reader = get_chunk_readers(page_bytes, pointer)
                     page_num, =  unsigned_long.unpack(cell_num_reader(4))
                     yield from process_if_buffered_or_remember(process_index_page, page_num)
@@ -264,9 +267,9 @@ def stream_sqlite(sqlite_chunks):
 
         def process_freelist_trunk_page(page_bytes, page_reader):
             next_trunk, num_leaves = freelist_trunk_header.unpack(page_reader(8))
-            leaf_pages = unpack('>{}L'.format(num_leaves), page_reader(num_leaves * 4))
+            leaf_pages = unsigned_long.iter_unpack(page_reader(num_leaves * 4))
 
-            for page_num in leaf_pages:
+            for page_num, in leaf_pages:
                 yield from process_if_buffered_or_remember(process_freelist_leaf_page, page_num)
 
             if next_trunk != 0:
